@@ -2,7 +2,7 @@
    nslcd.c - ldap local connection daemon
 
    Copyright (C) 2006 West Consulting
-   Copyright (C) 2006-2016 Arthur de Jong
+   Copyright (C) 2006-2018 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -121,7 +121,7 @@ static void display_version(FILE *fp)
 {
   fprintf(fp, "%s\n", PACKAGE_STRING);
   fprintf(fp, "Written by Luke Howard and Arthur de Jong.\n\n");
-  fprintf(fp, "Copyright (C) 1997-2016 Luke Howard, Arthur de Jong and West Consulting\n"
+  fprintf(fp, "Copyright (C) 1997-2017 Luke Howard, Arthur de Jong and West Consulting\n"
               "This is free software; see the source for copying conditions.  There is NO\n"
               "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 }
@@ -417,7 +417,7 @@ static void handleconnection(int sock, MYLDAP_SESSION *session)
     case NSLCD_ACTION_SERVICE_ALL:      (void)nslcd_service_all(fp, session); break;
     case NSLCD_ACTION_SHADOW_BYNAME:    (void)nslcd_shadow_byname(fp, session, uid); break;
     case NSLCD_ACTION_SHADOW_ALL:
-      if (!nslcd_cfg->nss_disable_enumeration) (void)nslcd_shadow_all(fp, session, uid); break;
+      if (!nslcd_cfg->nss_disable_enumeration) (void)nslcd_shadow_all(fp, session, uid);
       break;
     case NSLCD_ACTION_PAM_AUTHC:        (void)nslcd_pam_authc(fp, session, uid); break;
     case NSLCD_ACTION_PAM_AUTHZ:        (void)nslcd_pam_authz(fp, session); break;
@@ -769,8 +769,6 @@ int main(int argc, char *argv[])
     exit(EXIT_FAILURE);
   }
   adjust_oom_score();
-  /* create socket */
-  nslcd_serversocket = create_socket(NSLCD_SOCKET);
   /* start subprocess to do invalidating if reconnect_invalidate is set */
   for (i = 0; i < LM_NONE; i++)
     if (nslcd_cfg->reconnect_invalidate[i])
@@ -825,6 +823,8 @@ int main(int argc, char *argv[])
     }
     log_log(LOG_DEBUG, "setuid(%lu) done", (unsigned long int)nslcd_cfg->uid);
   }
+  /* create socket */
+  nslcd_serversocket = create_socket(NSLCD_SOCKET);
   /* start worker threads */
   log_log(LOG_INFO, "accepting connections");
   nslcd_threads = (pthread_t *)malloc(nslcd_cfg->threads * sizeof(pthread_t));
@@ -894,5 +894,5 @@ int main(int argc, char *argv[])
       log_log(LOG_ERR, "thread %d is still running, shutting down anyway", i);
   }
   /* we're done */
-  return EXIT_FAILURE;
+  return EXIT_SUCCESS;
 }
